-- bootstraping
local lazypath = vim.fn.stdpath("data") .. "/lazy/lazy.nvim"
if not vim.loop.fs_stat(lazypath) then
	vim.fn.system({
		"git",
		"clone",
		"--filter=blob:none",
		"https://github.com/folke/lazy.nvim.git",
		"--branch=stable", -- latest stable release
		lazypath,
	})
end
vim.opt.rtp:prepend(lazypath)

-- plugins installation and configuration
require("lazy").setup({
	-- LSP Support
	"neovim/nvim-lspconfig",
	-- lsp download manager
	"williamboman/mason.nvim",
	-- automatic lsp setup
	"williamboman/mason-lspconfig.nvim",
	-- additional formater support
	"stevearc/conform.nvim",
	-- additional linter support
	"mfussenegger/nvim-lint",
	-- mason autoinstaller for formatter's and linter's
	"WhoIsSethDaniel/mason-tool-installer.nvim",

	-- Adds git related signs to the gutter, as well as utilities for managing changes
	"lewis6991/gitsigns.nvim",

	{
		"folke/neodev.nvim",
		opts = {
			override = function(rood_dir, library)
				-- Make sure neodev load's in directory where I'm making my own plugins
				if rood_dir:find(os.getenv("HOME") .. "/repos/neovim/plugins/", 1, true) == 1 then
					library.enabled = true
					library.plugins = true
				end
			end,
		},
	},

	{
		-- Catppuccin, the best pastell color scheme
		"catppuccin/nvim",
		name = "catppuccin",
		priority = 1000,
	},

	-- Fuzzy Finder (files, lsp, etc)
	{
		"nvim-telescope/telescope.nvim",
		dependencies = {
			"nvim-lua/plenary.nvim",
			"nvim-telescope/telescope-ui-select.nvim",
			{
				"nvim-telescope/telescope-fzf-native.nvim",
				build = "make",
			},
		},
	},

	{
		-- Highlight, edit, and navigate code
		"nvim-treesitter/nvim-treesitter",
		build = ":TSUpdate",
	},

	{
		-- netrw on crack
		"stevearc/oil.nvim",
		opts = {},
		-- Optional dependencies
		dependencies = { "nvim-tree/nvim-web-devicons", lazy = true },
	},

	{
		-- harpoon your way around code
		{
			"ThePrimeagen/harpoon",
			branch = "harpoon2",
			requires = { "nvim-lua/plenary.nvim", lazy = true },
		},
	},

	-- Trying out writting plugins
	{ dir = "~/repos/neovim/plugins/md-tools.nvim" },

	-- Minimal neovim modules for a lot of things
	{ "echasnovski/mini.nvim" },
}, {
	install = {
		colorscheme = { "catppuccin" },
	},
	performance = {
		rtp = {
			disabled_plugins = {
				"gzip",
				"netrwPlugin",
				"tarPlugin",
				"tohtml",
				"tutor",
				"zipPlugin",
			},
		},
	},
})
